@@ -68,8 +68,13 @@ class dbd_bot():
 		self._prefix=info["prefix"]
 		self._token=info["token"]
 		self._codes={}
+		self._codes["event"]={}
+		self._codes["command"]={}
 		self._cooldown={}
 		self._db=_variables()
+		self._cmds=[]
+		self._cs=0
+		self._nowcmd=""
 		try:
 			self._debug=info["debug"]=="true"
 		except:
@@ -102,7 +107,7 @@ class dbd_bot():
 		self._client.remove_command(help)
 
 	def command(self, info):
-		self._codes["command:"+info["name"]]={}
+		self._codes["command"][info["name"]]={}
 		code=[]
 		for n in info:
 			if not n in ["name","prefix","program"]:
@@ -112,15 +117,15 @@ class dbd_bot():
 				code=reversed(code)
 		except:
 			info["program"]="classic"
-		self._codes["command:"+info["name"]]["name"]=info["name"]
-		self._codes["command:"+info["name"]]["code"]=code
+		self._codes["command"][info["name"]]["name"]=info["name"]
+		self._codes["command"][info["name"]]["code"]=code
 		try:
 			self._codes["command:"+info["name"]]["prefix"]=info["prefix"]
 		except:
-			self._codes["command:"+info["name"]]["prefix"]=self._prefix
+			self._codes["command"][info["name"]]["prefix"]=self._prefix
 		
 	def event(self, info):
-		self._codes[info["name"]]={}
+		self._codes["event"][info["name"]]={}
 		code=[]
 		for n in info:
 			if not n in ["name","program"]:
@@ -130,13 +135,16 @@ class dbd_bot():
 				code=reversed(code)
 		except:
 			info["program"]="classic"
-		self._codes[info["name"]]["name"]=info["name"]
-		self._codes[info["name"]]["code"]=code
+		self._codes["event"][info["name"]]["name"]=info["name"]
+		self._codes["event"][info["name"]]["code"]=code
 
 	def var(self, info):
 		self._db.vars[info["name"]]=info["value"]
 
 	def run(self):
+		for c in self._codes["command"]:
+			self._cmds.append(self._codes["command"][c]["name"])
+			self._cs+=1
 		_start(self._client, self)
 
 def _start(client, bot):
@@ -242,11 +250,7 @@ def _start(client, bot):
 		line=line.replace("%time%",str(timerep))
 		line=line.replace("$uptime",str(int(time.time() - startTime)))
 		line=line.replace("$ping",str(round(client.latency*800)))
-		cs=0
-		for c in bot._codes:
-			if c.startswith("command:"):
-				cs+=1
-		line=line.replace("$commandsCount",str(cs))
+		line=line.replace("$commandsCount",str(bot._cs))
 		try:
 			line=line.replace("$membersCount",str(len(guild.members)-1))
 			check=[]
@@ -331,6 +335,17 @@ def _start(client, bot):
 					line=line.replace("$roleID"+bot._style[0]+line.split("$roleID"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],str(role.id))
 				except Exception as e:
 					line=line.replace("$roleID"+bot._style[0]+line.split("$roleID"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],"none")
+		while "$serverInvite"+bot._style[0] in line:
+			if nowloop==line:
+				break
+			else:
+				nowloop=line
+				try:
+					need = discord.utils.get(client.guilds, id=int(line.split("$serverInvite"+bot._style[0])[-1].split(bot._style[1])[0]))
+					inv = await need.channels[0].create_invite(max_age = 300)
+					line=line.replace("$serverInvite"+bot._style[0]+line.split("$serverInvite"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],str(inv))
+				except Exception as e:
+					line=line.replace("$serverInvite"+bot._style[0]+line.split("$serverInvite"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],"none")
 		while "$boostCount"+bot._style[0] in line:
 			if nowloop==line:
 				break
@@ -477,7 +492,7 @@ def _start(client, bot):
 			else:
 				nowloop=line
 				try:
-					r=line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0].replace(line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1],line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[2])
+					r=line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0].replace(line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1],line[len(line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[0]+";"+line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0].split(bot._separator)[1]+";"):])
 					line=line.replace("$replaceText"+bot._style[0]+line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],str(r))
 				except:
 					line=line.replace("$replaceText"+bot._style[0]+line.split("$replaceText"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1],"none") 
@@ -555,7 +570,7 @@ def _start(client, bot):
 					line=line.replace("$checkCondition"+bot._style[0]+line.split("$checkCondition"+bot._style[0])[-1].split(bot._style[1])[0]+bot._style[1], "none")
 		return line
 	
-	async def use(message, name, trigger=""):
+	async def use(message, name, trigger, type):
 		vars={}
 		restart=True
 		while restart:
@@ -573,12 +588,15 @@ def _start(client, bot):
 			elif name=="onJoined":
 				guild=message.guild
 				author=message
+			elif name=="onBotJoin":
+				guild=message
+				author=client.user
 			else:
 				guild=message.guild
 				ctx=message.channel
 				author=message.author
 				content=message.content.lstrip(trigger).lstrip(" ")
-			for line in bot._codes[name]["code"]:
+			for line in bot._codes[type][name]["code"]:
 				if "$eval" in line:
 					for l in content.split("\n"):
 						lines.append(l)
@@ -1212,14 +1230,21 @@ def _start(client, bot):
 							bot._db.data["global"][str(m.id)][v]=bot._db.vars[v]
 		bot._db.save()
 		try:
-			await use("", "botReady", "")
+			await use("", "botReady", "", "event")
 		except Exception as e:
 			pass
 
 	@client.event
 	async def on_member_join(user):
 		try:
-			await use(user, "onJoined", "")
+			await use(user, "onJoined", "", "event")
+		except Exception as e:
+			pass
+	
+	@client.event
+	async def on_guild_join(guild):
+		try:
+			await use(guild, "onBotJoin", "", "event")
 		except Exception as e:
 			pass
 	
@@ -1228,39 +1253,12 @@ def _start(client, bot):
 		if not message.author.bot:
 			if str(message.content).startswith(bot._client.user.mention):
 				if bot._help:
-					cmds=""
-					for c in bot._codes:
-						if c.startswith("command:"):
-							cmds+=bot._codes[c]["name"]+"\n"
-					await message.channel.send(embed=discord.Embed(title="Комманды("+str(len(cmds.split("\n"))-1)+")",description=f"```py\n{cmds}\n```"))
-			for cmd in bot._codes:
-				if cmd.startswith("command:"):
-					if "$case" in bot._codes[cmd]["code"]:
-						if str(bot._codes[cmd]["name"]).startswith("[") and str(bot._codes[cmd]["name"]).endswith("]"):
-							triggers=bot._codes[cmd]["name"].lstrip("[")
-							triggers=triggers.rstrip("]")
-							triggers=triggers.split(bot._separator)
-							for trigger in triggers:
-								trigger=await replaces(str(bot._codes[cmd]["prefix"]+trigger), message, message.guild, message.content.lstrip(str(bot._codes[cmd]["prefix"]+trigger).lower()).lstrip(" "), "", {}, 0, "")
-								if str(message.content).lower().startswith(str(trigger).lower()):
-									await use(message, cmd, bot._codes[cmd]["prefix"]+trigger)
-						else:
-							trigger=await replaces(str(bot._codes[cmd]["prefix"]+bot._codes[cmd]["name"]), message, message.guild, message.content.lstrip(str(bot._codes[cmd]["prefix"]+bot._codes[cmd]["name"])).lstrip(" "), "", {}, 0, "")
-							if str(message.content).lower().startswith(trigger.lower()):
-								await use(message, cmd, bot._codes[cmd]["prefix"]+bot._codes[cmd]["name"])
-					else:
-						if str(bot._codes[cmd]["name"]).startswith("[") and str(bot._codes[cmd]["name"]).endswith("]"):
-							triggers=bot._codes[cmd]["name"].lstrip("[")
-							triggers=triggers.rstrip("]")
-							triggers=triggers.split(bot._separator)
-							for trigger in triggers:
-								trigger=await replaces(str(bot._codes[cmd]["prefix"]+trigger), message, message.guild, message.content.lstrip(trigger).lstrip(" "), "", {}, 0, "")
-								if str(message.content).startswith(trigger):
-									await use(message, cmd, bot._codes[cmd]["prefix"]+trigger)
-						else:
-							trigger=await replaces(str(bot._codes[cmd]["prefix"]+bot._codes[cmd]["name"]), message, message.guild, message.content.lstrip(str(bot._codes[cmd]["prefix"]+bot._codes[cmd]["name"])).lstrip(" "), "", {}, 0, "")
-							if str(message.content).startswith(trigger):
-								await use(message, cmd, bot._codes[cmd]["prefix"]+bot._codes[cmd]["name"])
+					await message.channel.send(embed=discord.Embed(title="Комманды("+str(len(bot._cmds)-1)+")",description=f"```py\n"+"\n".join(bot._cmds)+"\n```"))
+			def remember(text):
+				bot._nowcmd=text
+				return True
+			if any(cmd in message.content[:len(max(bot._cmds, key=len))] and remember(cmd) for cmd in bot._codes["command"]):
+				await use(message, bot._nowcmd, bot._codes["command"][bot._nowcmd]["prefix"]+bot._codes["command"][bot._nowcmd]["name"], "command")
 	if bot._self:
 		client.run(bot._token, bot=False)
 	else:
